@@ -1,6 +1,6 @@
 /*
  * Copyright 2014 Canonical Ltd.
- * Copyright 2023 Robert Tari
+ * Copyright 2023-2024 Robert Tari
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -76,7 +76,7 @@ public:
     {
         if (ayatana_common_utils_is_lomiri()) {
 
-            GSettingsSchema *pSchema = g_settings_schema_source_lookup(pSource, "com.lomiri.touch.system", FALSE);
+            GSettingsSchema *pSchema = g_settings_schema_source_lookup(pSource, "com.lomiri.touch.system", TRUE);
 
             if (pSchema != NULL)
             {
@@ -91,7 +91,7 @@ public:
         }
         else {
 
-            GSettingsSchema *pSchema = g_settings_schema_source_lookup(pSource, "org.ayatana.indicator.display", FALSE);
+            GSettingsSchema *pSchema = g_settings_schema_source_lookup(pSource, "org.ayatana.indicator.display", TRUE);
 
             if (pSchema != NULL)
             {
@@ -134,7 +134,7 @@ public:
                     }
                 }
 
-                pSchema = g_settings_schema_source_lookup (pSource, sSchema, FALSE);
+                pSchema = g_settings_schema_source_lookup (pSource, sSchema, TRUE);
 
                 if (pSchema != NULL)
                 {
@@ -146,7 +146,7 @@ public:
                     g_error("No %s schema could be found", sSchema);
                 }
 
-                pSchema = g_settings_schema_source_lookup (pSource, sCursorSchema, FALSE);
+                pSchema = g_settings_schema_source_lookup (pSource, sCursorSchema, TRUE);
 
                 if (pSchema != NULL)
                 {
@@ -158,7 +158,7 @@ public:
                     g_error("No %s schema could be found", sCursorSchema);
                 }
 
-                pSchema = g_settings_schema_source_lookup (pSource, sMetacitySchema, FALSE);
+                pSchema = g_settings_schema_source_lookup (pSource, sMetacitySchema, TRUE);
 
                 if (pSchema != NULL)
                 {
@@ -179,7 +179,7 @@ public:
                     sSchema = "org.gnome.desktop.interface";
                 }
 
-                pSchema = g_settings_schema_source_lookup (pSource, sSchema, FALSE);
+                pSchema = g_settings_schema_source_lookup (pSource, sSchema, TRUE);
 
                 if (pSchema != NULL)
                 {
@@ -334,7 +334,7 @@ private:
 #ifdef COLOR_TEMP_ENABLED
     static void onUserChanged (GDBusConnection *pConnection, const gchar *sSender, const gchar *sPath, const gchar *sInterface, const gchar *sSignal, GVariant *pParameters, gpointer pUserData)
     {
-        DisplayIndicator::Impl *pImpl = (DisplayIndicator::Impl*) pUserData;
+        DisplayIndicator::Impl *pImpl = static_cast<DisplayIndicator::Impl*>(pUserData);
         g_variant_get (pParameters, "(s)", &pImpl->sUser);
         loadManager (pImpl);
     }
@@ -449,7 +449,7 @@ private:
 
     static gboolean updateColor (gpointer pData)
     {
-        DisplayIndicator::Impl *pImpl = (DisplayIndicator::Impl*) pData;
+        DisplayIndicator::Impl *pImpl = static_cast<DisplayIndicator::Impl*>(pData);
 
         if (pImpl->bReadingAccountsService)
         {
@@ -760,7 +760,7 @@ private:
 
     static void onGeoClueLoaded (GObject *pObject, GAsyncResult *pResult, gpointer pData)
     {
-        DisplayIndicator::Impl *pImpl = (DisplayIndicator::Impl*) pData;
+        DisplayIndicator::Impl *pImpl = static_cast<DisplayIndicator::Impl*>(pData);
         GError *pError = NULL;
         GClueSimple *pSimple = gclue_simple_new_finish (pResult, &pError);
 
@@ -816,7 +816,7 @@ private:
     {
         g_simple_action_set_state (pAction, pVariant);
 
-        DisplayIndicator::Impl *pImpl = (DisplayIndicator::Impl*) pData;
+        DisplayIndicator::Impl *pImpl = static_cast<DisplayIndicator::Impl*>(pData);
 
         if (pImpl->bAutoSliderUpdate)
         {
@@ -1014,7 +1014,8 @@ private:
         g_menu_item_set_attribute_value (menu_item, "max-icon", pIconMaxSerialised);
         g_menu_item_set_attribute (menu_item, "min-value", "d", 0.5);
         g_menu_item_set_attribute (menu_item, "max-value", "d", 1.0);
-        g_menu_item_set_attribute (menu_item, "step", "d", 0.005);
+        g_menu_item_set_attribute (menu_item, "step", "d", 0.01);
+        g_menu_item_set_attribute (menu_item, "digits", "y", 2);
         g_menu_append_item (section, menu_item);
 
         pIconMin = g_themed_icon_new_with_default_fallbacks ("ayatana-indicator-display-colortemp-on");
@@ -1029,6 +1030,7 @@ private:
         g_menu_item_set_attribute (menu_item, "min-value", "d", 3000.0);
         g_menu_item_set_attribute (menu_item, "max-value", "d", 6500.0);
         g_menu_item_set_attribute (menu_item, "step", "d", 100.0);
+        g_menu_item_set_attribute (menu_item, "digits", "y", 0);
         g_menu_append_item (section, menu_item);
 
         GMenu *pMenuProfiles = g_menu_new ();
@@ -1141,8 +1143,8 @@ private:
   GSettings *pMetacitySettings = NULL;
   GSettings *pColorSchemeSettings = NULL;
   gboolean bTest;
-  guint nGreeterSubscription;
-  GDBusConnection *pConnection;
+  guint nGreeterSubscription = 0;
+  GDBusConnection *pConnection = NULL;
   gchar *sUser = NULL;
   GSList *lUsers = NULL;
   gboolean bReadingAccountsService = FALSE;
